// ****************************************************************
//
//   IBM Confidential
//   OCO Source Materials
//   <<PART NUMBER - 5724-B75>>
//   (C) Copyright IBM Corp. 2001 - All Rights Reserved.
//   US Government Users Restricted Rights - Use, duplication or disclosure
//   restricted by GSA ADP Schedule Contract with IBM Corp.
//
// ****************************************************************
package com.ibm.etools.cobol.importer;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Vector;

import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.preference.IPreferenceStore;

import com.ibm.etools.cobol.plugin.CobolPlugin;
import com.ibm.etools.logging.util.Level;

public class CobolPreferenceStore implements ICobolPreferenceConstants {

	private static final String copyright = "(c) Copyright IBM Corporation 2002.";
	public static final HashMap defaultValues = new HashMap();
	
	static {
		defaultValues.put(PRE_COBOL_PLATFORM_SELECTION, new Integer(DEFAULT_PS));
		defaultValues.put(PRE_COBOL_CODEPAGE, DEFAULT_CODEPAGE);
		defaultValues.put(PRE_COBOL_HOST_CODEPAGE_EC, OS_CODEPAGE);		
		defaultValues.put(PRE_COBOL_FLOATING_POINT_FORMAT, new Integer(DEFAULT_FPT));
		defaultValues.put(PRE_COBOL_EXT_DECIMAL_SIGN, DECIMAL_ASCII);
		defaultValues.put(PRE_COBOL_ENDIAN, ENDIAN_LITTLE);
		defaultValues.put(PRE_COBOL_REMOTE_ENDIAN, ENDIAN_LITTLE);
		defaultValues.put(PRE_COBOL_COMPILE_TIME_LOCALE, 
				getLocale((new COBOLLocaleRelatedConstants()).getLocaleNames()));
		defaultValues.put(PRE_COBOL_ASCII_CODEPAGE, new Integer(DEFAULT_ASCII_CODEPAGE));
		defaultValues.put(PRE_COBOL_ERROR_MSGS_LANG,
				getLocale((new COBOLLocaleRelatedConstants()).getErrorMessagesLanguage()));		
		defaultValues.put(PRE_COBOL_CURRENCY, DEFAULT_CURRENCY);
		defaultValues.put(PRE_COBOL_SOSI, new Boolean(false));
		defaultValues.put(PRE_COBOL_TRUNC, TRUNC_STD);
		defaultValues.put(PRE_COBOL_NUMPROC, NUMPROC_PFD);
		defaultValues.put(PRE_COBOL_NSYMBOL, NSYMBOL_NATIONAL);
		defaultValues.put(PRE_COBOL_QUOTE, QUOTE_DOUBLE);
		defaultValues.put(PRE_COBOL_COLLSEQ, COLLSEQ_BIN);
		defaultValues.put(PRE_COBOL_NCOLLSEQ, NCOLLSEQ_BIN);		
		defaultValues.put(PRE_COBOL_EXTENSION_CBL, DEFAULT_ES);
		defaultValues.put(PRE_COBOL_EXTENSION_CCP, DEFAULT_ES);
		defaultValues.put(PRE_COBOL_EXTENSION_COB, DEFAULT_ES);
		defaultValues.put(PRE_COBOL_EXTENSION_CPY, NOT_DEFAULT_ES);		
	};

	public static HashMap getValues() {

//		IPreferenceStore store = ScriptPreferencePageRegistry.getInstance(PLUGIN_ID).getPreferenceStore();
		CobolPlugin p = CobolPlugin.getPlugin();
		IPreferenceStore store = null;
		if (p!= null)
			store = CobolPlugin.getPlugin().getPreferenceStore();		
		if (store == null) {
			return (HashMap)defaultValues.clone();
		}
		
		HashMap iStorage = (HashMap)defaultValues.clone();
		String work;
		int iValue = 0;
		boolean bValue = false;
		

		// get saved preference store platform selection
		if (store.contains(PRE_COBOL_PLATFORM_SELECTION)) {
			iValue = store.getInt(PRE_COBOL_PLATFORM_SELECTION);
			iStorage.put(
				(Object) PRE_COBOL_PLATFORM_SELECTION,
				(Object) new Integer(iValue));
		}

		// get saved preference store codepage
		work = store.getString(PRE_COBOL_CODEPAGE);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object) PRE_COBOL_CODEPAGE, (Object) work);
		}
		
		// get saved preference store FPF
		if (store.contains(PRE_COBOL_FLOATING_POINT_FORMAT)) {
			iValue = store.getInt(PRE_COBOL_FLOATING_POINT_FORMAT);
			iStorage.put(
				(Object) PRE_COBOL_FLOATING_POINT_FORMAT,
				(Object) new Integer(iValue));
		}

		// get saved preference store ENDIAN
		work = store.getString(PRE_COBOL_ENDIAN);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object)PRE_COBOL_ENDIAN, (Object)work);
		}

		// get saved preference store REMOTE ENDIAN
		work = store.getString(PRE_COBOL_REMOTE_ENDIAN);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object)PRE_COBOL_REMOTE_ENDIAN, (Object)work);
		}

		// get saved preference store EXT_DECIMAL_SIGN
		work = store.getString(PRE_COBOL_EXT_DECIMAL_SIGN);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object)PRE_COBOL_EXT_DECIMAL_SIGN, (Object)work);
		}

		// get saved preference store host codepage for external decimals (ebcdic Custom)
		work = store.getString(PRE_COBOL_HOST_CODEPAGE_EC);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object) PRE_COBOL_HOST_CODEPAGE_EC, (Object) work);
		}
		
		
		// get saved preference store COMPILE TIME LOCALE
		if (store.contains(PRE_COBOL_COMPILE_TIME_LOCALE)) {
			iValue = store.getInt(PRE_COBOL_COMPILE_TIME_LOCALE);
			iStorage.put(
				(Object) PRE_COBOL_COMPILE_TIME_LOCALE,
				(Object) new Integer(iValue));
		} else {
			iStorage.put(
					(Object) PRE_COBOL_COMPILE_TIME_LOCALE,
					(Object) new Integer(0));			
		}

		// get saved preference store ASCII CODEPAGE
		if (store.contains(PRE_COBOL_ASCII_CODEPAGE)) {
			iValue = store.getInt(PRE_COBOL_ASCII_CODEPAGE);			
			iStorage.put(
				(Object) PRE_COBOL_ASCII_CODEPAGE,
				(Object) new Integer(iValue));
		}

		// get saved preference store ERROR MESSAGES LANGUAGE
		if (store.contains(PRE_COBOL_ERROR_MSGS_LANG)) {
			iValue = store.getInt(PRE_COBOL_ERROR_MSGS_LANG);
			iStorage.put(
				(Object) PRE_COBOL_ERROR_MSGS_LANG,
				(Object) new Integer(iValue));
		} else {
			iStorage.put(
					(Object) PRE_COBOL_ERROR_MSGS_LANG,
					(Object) new Integer(0));			
		}

		// get saved preference store currency
		work = store.getString(PRE_COBOL_CURRENCY);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object) PRE_COBOL_CURRENCY, (Object) work);
		}		
		
		// get saved preference store SOSI
		if (store.contains(PRE_COBOL_SOSI)) {
			bValue = store.getBoolean(PRE_COBOL_SOSI);
			iStorage.put(
				(Object) PRE_COBOL_SOSI,
				(Object) new Boolean(bValue));
		}
		
		// get saved preference store trunc
		work = store.getString(PRE_COBOL_TRUNC);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object)PRE_COBOL_TRUNC, (Object)work);
		}


		// get saved preference store nsymbol
		work = store.getString(PRE_COBOL_NSYMBOL);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object)PRE_COBOL_NSYMBOL, (Object)work);
		}

		// get saved preference store QUOTE
		work = store.getString(PRE_COBOL_QUOTE);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object)PRE_COBOL_QUOTE, (Object)work);
		}

		// get saved preference store collseq
		work = store.getString(PRE_COBOL_COLLSEQ);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object)PRE_COBOL_COLLSEQ, (Object)work);
		}
		
		// get saved preference store ncollseq
		work = store.getString(PRE_COBOL_NCOLLSEQ);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object)PRE_COBOL_NCOLLSEQ, (Object)work);
		}			

		// get saved file extension (CBL) support
		work = store.getString(PRE_COBOL_EXTENSION_CBL);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object)PRE_COBOL_EXTENSION_CBL, (Object)work);
		}

		// get saved file extension (CCP) support
		work = store.getString(PRE_COBOL_EXTENSION_CCP);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object)PRE_COBOL_EXTENSION_CCP, (Object)work);
		}

		// get saved file extension (COB) support
		work = store.getString(PRE_COBOL_EXTENSION_COB);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object)PRE_COBOL_EXTENSION_COB, (Object)work);
		}		
		// get saved file extension (CPY) support
		work = store.getString(PRE_COBOL_EXTENSION_CPY);
		if ((work != null) && (work.length() > 0)) {
			iStorage.put((Object)PRE_COBOL_EXTENSION_CPY, (Object)work);
		}
		
		return iStorage;

	}
	
	/**
	 * @return
	 */
	private static Integer getLocale(Vector v) {
		String currentLocale = Platform.getNL();
		int localeIndex = 0;
		boolean foundEntry = false;
		Iterator iter = v.iterator();
		while(iter.hasNext()){
			if (((String) iter.next()).equalsIgnoreCase(currentLocale)) {
				foundEntry = true;
				break;
			}
			localeIndex++;				
		}
		if (!foundEntry) {
			CobolPlugin.getPlugin().writeMsg(Level.FINE,"****CobolPreferenceStore.getLocale(): CurrentLocale = |" + currentLocale + "| not found, so defaulting to english");			
			localeIndex = 0;
		}
		CobolPlugin.getPlugin().writeMsg(Level.FINE,"****CobolPreferenceStore.getLocale(): Locale = |" + localeIndex + "|");
		return new Integer(localeIndex);
	}

	public static HashMap getDefaultValues() {
		return (HashMap)defaultValues.clone();
	}
}
